errors

package
v1.27.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 5, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ParseQueryError

func ParseQueryError(header string) (string, smithy.ErrorFault)

ParseQueryError extracts the error code and fault from X-Amzn-Query-Error.

func SanitizeErrorCode

func SanitizeErrorCode(code string) string

SanitizeErrorCode strips namespace prefixes and colon suffixes from protocol error codes.

func SetErrorCodeOverride

func SetErrorCodeOverride(err error, code string)

SetErrorCodeOverride sets the ErrorCodeOverride field on err if present.

This is used by protocols in awsquery-compatible mode that need to override the error code on a deserialized error.

Types

This section is empty.

Jump to