Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ParseQueryError ¶
func ParseQueryError(header string) (string, smithy.ErrorFault)
ParseQueryError extracts the error code and fault from X-Amzn-Query-Error.
func SanitizeErrorCode ¶
SanitizeErrorCode strips namespace prefixes and colon suffixes from protocol error codes.
func SetErrorCodeOverride ¶
SetErrorCodeOverride sets the ErrorCodeOverride field on err if present.
This is used by protocols in awsquery-compatible mode that need to override the error code on a deserialized error.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.