Documentation
¶
Overview ¶
Package traits defines representations of Smithy IDL traits that appear in code-generated schemas.
Index ¶
- type AWSQueryCompatible
- type AWSQueryError
- type ContextParam
- type EC2QueryName
- type EventHeader
- type EventPayload
- type HTTP
- type HTTPError
- type HTTPHeader
- type HTTPLabel
- type HTTPPayload
- type HTTPPrefixHeaders
- type HTTPQuery
- type HTTPQueryParams
- type HTTPResponseCode
- type HostLabel
- type JSONName
- type MediaType
- type Sensitive
- type Streaming
- type TimestampFormat
- type UnitShape
- type XMLAttribute
- type XMLFlattened
- type XMLName
- type XMLNamespace
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AWSQueryCompatible ¶
type AWSQueryCompatible struct{}
AWSQueryCompatible represents aws.protocols#awsQueryCompatible.
func (*AWSQueryCompatible) TraitID ¶
func (*AWSQueryCompatible) TraitID() smithy.ShapeID
TraitID identifies the trait.
type AWSQueryError ¶
AWSQueryError represents aws.protocols#awsQueryError.
func (*AWSQueryError) TraitID ¶
func (*AWSQueryError) TraitID() smithy.ShapeID
TraitID identifies the trait.
func (*AWSQueryError) TraitIndex ¶
func (*AWSQueryError) TraitIndex() int
TraitIndex implements smithy.IndexableTrait.
type ContextParam ¶
type ContextParam struct{}
ContextParam represents smithy.rules#contextParam.
func (*ContextParam) TraitID ¶
func (*ContextParam) TraitID() smithy.ShapeID
TraitID identifies the trait.
func (*ContextParam) TraitIndex ¶
func (*ContextParam) TraitIndex() int
TraitIndex implements smithy.IndexableTrait.
type EC2QueryName ¶
type EC2QueryName struct {
Name string
}
EC2QueryName represents aws.protocols#ec2QueryName.
func (*EC2QueryName) TraitID ¶
func (*EC2QueryName) TraitID() smithy.ShapeID
TraitID identifies the trait.
func (*EC2QueryName) TraitIndex ¶
func (*EC2QueryName) TraitIndex() int
TraitIndex implements smithy.IndexableTrait.
type EventHeader ¶
type EventHeader struct{}
EventHeader represents smithy.api#eventHeader.
func (*EventHeader) TraitID ¶
func (*EventHeader) TraitID() smithy.ShapeID
TraitID identifies the trait.
func (*EventHeader) TraitIndex ¶
func (*EventHeader) TraitIndex() int
TraitIndex implements smithy.IndexableTrait.
type EventPayload ¶
type EventPayload struct{}
EventPayload represents smithy.api#eventPayload.
func (*EventPayload) TraitID ¶
func (*EventPayload) TraitID() smithy.ShapeID
TraitID identifies the trait.
func (*EventPayload) TraitIndex ¶
func (*EventPayload) TraitIndex() int
TraitIndex implements smithy.IndexableTrait.
type HTTP ¶
HTTP represents smithy.api#http.
func (*HTTP) TraitIndex ¶
TraitIndex implements smithy.IndexableTrait.
type HTTPError ¶
type HTTPError struct {
Code int
}
HTTPError represents smithy.api#httpError.
func (*HTTPError) TraitIndex ¶
TraitIndex implements smithy.IndexableTrait.
type HTTPHeader ¶
type HTTPHeader struct {
Name string
}
HTTPHeader represents smithy.api#httpHeader.
func (*HTTPHeader) TraitID ¶
func (*HTTPHeader) TraitID() smithy.ShapeID
TraitID identifies the trait.
func (*HTTPHeader) TraitIndex ¶
func (*HTTPHeader) TraitIndex() int
TraitIndex implements smithy.IndexableTrait.
type HTTPLabel ¶
type HTTPLabel struct{}
HTTPLabel represents smithy.api#httpLabel.
func (*HTTPLabel) TraitIndex ¶
TraitIndex implements smithy.IndexableTrait.
type HTTPPayload ¶
type HTTPPayload struct{}
HTTPPayload represents smithy.api#httpPayload.
func (*HTTPPayload) TraitID ¶
func (*HTTPPayload) TraitID() smithy.ShapeID
TraitID identifies the trait.
func (*HTTPPayload) TraitIndex ¶
func (*HTTPPayload) TraitIndex() int
TraitIndex implements smithy.IndexableTrait.
type HTTPPrefixHeaders ¶
type HTTPPrefixHeaders struct {
Prefix string
}
HTTPPrefixHeaders represents smithy.api#httpPrefixHeaders.
func (*HTTPPrefixHeaders) TraitID ¶
func (*HTTPPrefixHeaders) TraitID() smithy.ShapeID
TraitID identifies the trait.
func (*HTTPPrefixHeaders) TraitIndex ¶
func (*HTTPPrefixHeaders) TraitIndex() int
TraitIndex implements smithy.IndexableTrait.
type HTTPQuery ¶
type HTTPQuery struct {
Name string
}
HTTPQuery represents smithy.api#httpQuery.
func (*HTTPQuery) TraitIndex ¶
TraitIndex implements smithy.IndexableTrait.
type HTTPQueryParams ¶
type HTTPQueryParams struct{}
HTTPQueryParams represents smithy.api#httpQueryParams.
func (*HTTPQueryParams) TraitID ¶
func (*HTTPQueryParams) TraitID() smithy.ShapeID
TraitID identifies the trait.
func (*HTTPQueryParams) TraitIndex ¶
func (*HTTPQueryParams) TraitIndex() int
TraitIndex implements smithy.IndexableTrait.
type HTTPResponseCode ¶
type HTTPResponseCode struct{}
HTTPResponseCode represents smithy.api#httpResponseCode.
func (*HTTPResponseCode) TraitID ¶
func (*HTTPResponseCode) TraitID() smithy.ShapeID
TraitID identifies the trait.
func (*HTTPResponseCode) TraitIndex ¶
func (*HTTPResponseCode) TraitIndex() int
TraitIndex implements smithy.IndexableTrait.
type HostLabel ¶
type HostLabel struct{}
HostLabel represents smithy.api#hostLabel.
func (*HostLabel) TraitIndex ¶
TraitIndex implements smithy.IndexableTrait.
type JSONName ¶
type JSONName struct {
Name string
}
JSONName represents smithy.api#jsonName.
func (*JSONName) TraitIndex ¶
TraitIndex implements smithy.IndexableTrait.
type MediaType ¶
type MediaType struct {
Type string
}
MediaType represents smithy.api#mediaType.
func (*MediaType) TraitIndex ¶
TraitIndex implements smithy.IndexableTrait.
type Sensitive ¶
type Sensitive struct{}
Sensitive represents smithy.api#sensitive.
func (*Sensitive) TraitIndex ¶
TraitIndex implements smithy.IndexableTrait.
type Streaming ¶
type Streaming struct{}
Streaming represents smithy.api#streaming.
func (*Streaming) TraitIndex ¶
TraitIndex implements smithy.IndexableTrait.
type TimestampFormat ¶
type TimestampFormat struct {
Format string
}
TimestampFormat represents smithy.api#timestampFormat.
func (*TimestampFormat) TraitID ¶
func (*TimestampFormat) TraitID() smithy.ShapeID
TraitID identifies the trait.
func (*TimestampFormat) TraitIndex ¶
func (*TimestampFormat) TraitIndex() int
TraitIndex implements smithy.IndexableTrait.
type UnitShape ¶
type UnitShape struct{}
UnitShape is a synthetic trait applied to input/output shapes that were backfilled from Unit. It indicates the shape has no defined members and should be treated as absent for protocol serialization purposes.
func (*UnitShape) TraitIndex ¶
TraitIndex implements smithy.IndexableTrait.
type XMLAttribute ¶
type XMLAttribute struct{}
XMLAttribute represents smithy.api#xmlAttribute.
func (*XMLAttribute) TraitID ¶
func (*XMLAttribute) TraitID() smithy.ShapeID
TraitID identifies the trait.
func (*XMLAttribute) TraitIndex ¶
func (*XMLAttribute) TraitIndex() int
TraitIndex implements smithy.IndexableTrait.
type XMLFlattened ¶
type XMLFlattened struct{}
XMLFlattened represents smithy.api#xmlFlattened.
func (*XMLFlattened) TraitID ¶
func (*XMLFlattened) TraitID() smithy.ShapeID
TraitID identifies the trait.
func (*XMLFlattened) TraitIndex ¶
func (*XMLFlattened) TraitIndex() int
TraitIndex implements smithy.IndexableTrait.
type XMLName ¶
type XMLName struct {
Name string
}
XMLName represents smithy.api#xmlName.
func (*XMLName) TraitIndex ¶
TraitIndex implements smithy.IndexableTrait.
type XMLNamespace ¶
XMLNamespace represents smithy.api#xmlNamespace.
func (*XMLNamespace) TraitID ¶
func (*XMLNamespace) TraitID() smithy.ShapeID
TraitID identifies the trait.
func (*XMLNamespace) TraitIndex ¶
func (*XMLNamespace) TraitIndex() int
TraitIndex implements smithy.IndexableTrait.